@@ -28,21 +28,21 @@
 #pod =for :this This is C<Dist::Zilla::Plugin::Hook> module documentation. Read this if you are going to hack or
 #pod extend C<Dist-Zilla-Plugin-Hook>.
 #pod
-#pod =for :that If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>. General
+#pod =for :those If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>. General
 #pod topics like getting source, building, installing, bug reporting and some others are covered in the
-#pod L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
+#pod F<README>.
 #pod
 #pod =head1 DESCRIPTION
 #pod
 #pod This plugin consumes C<Hooker> role like all other C<Hook> plugins. However, this plugin I<never>
-#pod executes its Perl code. Instead, it just stores it for later use by other plugins. As of today,
-#pod only C<Hook> plugin with C<prologue> name is actually used:
+#pod executes its Perl code. Instead, it just stores it for later use. As of today, only C<Hook> plugin
+#pod with C<prologue> name is actually used:
 #pod
 #pod     [Hook/prologue]
 #pod         . = use autodie ':all';
 #pod
-#pod specifies code, which will be executed as initial part of all other hooks. Again: C<Hook> itself
-#pod does not execute its code, if there is no other hooks in F<dist.ini>, this code will never execute.
+#pod Such code which will be executed just before each hook. Note again: C<Hook> itself does not execute
+#pod its code; if there are no other hooks in F<dist.ini>, this code will never execute.
 #pod
 #pod BTW, C<Dist::Zilla> and CPAN do not handle well distributions with no main module. This is also a
 #pod "main" module of C<Dist-Zilla-Plugin-Hook> distribution, to make C<Dist::Zilla> and C<CPAN> indexer happy.
@@ -52,7 +52,7 @@
 #pod =for :list
 #pod = L<Dist::Zilla>
 #pod = L<Dist::Zilla::Plugin::Hook::Manual>
-#pod = L<Dist::Zilla::Plugin::Hook::ReadMe>
+#pod = L<Dist::Zilla::Role::Hooker>
 #pod
 #pod =cut
 
@@ -62,7 +62,7 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: Write C<Dist::Zilla> plugin directly in F<dist.ini>
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 with 'Dist::Zilla::Role::Plugin';
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
@@ -100,7 +100,7 @@ Dist::Zilla::Plugin::Hook - Write C<Dist::Zilla> plugin directly in F<dist.ini>
 
 =head1 VERSION
 
-Version 0.006, released on 2015-08-11 20:12 UTC.
+Version 0.007, released on 2015-08-13 19:35 UTC.
 
 =head1 WHAT?
 
@@ -112,19 +112,19 @@ extend C<Dist-Zilla-Plugin-Hook>.
 
 If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>. General
 topics like getting source, building, installing, bug reporting and some others are covered in the
-L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
+F<README>.
 
 =head1 DESCRIPTION
 
 This plugin consumes C<Hooker> role like all other C<Hook> plugins. However, this plugin I<never>
-executes its Perl code. Instead, it just stores it for later use by other plugins. As of today,
-only C<Hook> plugin with C<prologue> name is actually used:
+executes its Perl code. Instead, it just stores it for later use. As of today, only C<Hook> plugin
+with C<prologue> name is actually used:
 
     [Hook/prologue]
         . = use autodie ':all';
 
-specifies code, which will be executed as initial part of all other hooks. Again: C<Hook> itself
-does not execute its code, if there is no other hooks in F<dist.ini>, this code will never execute.
+Such code which will be executed just before each hook. Note again: C<Hook> itself does not execute
+its code; if there are no other hooks in F<dist.ini>, this code will never execute.
 
 BTW, C<Dist::Zilla> and CPAN do not handle well distributions with no main module. This is also a
 "main" module of C<Dist-Zilla-Plugin-Hook> distribution, to make C<Dist::Zilla> and C<CPAN> indexer happy.
@@ -137,7 +137,7 @@ BTW, C<Dist::Zilla> and CPAN do not handle well distributions with no main modul
 
 =item L<Dist::Zilla::Plugin::Hook::Manual>
 
-=item L<Dist::Zilla::Plugin::Hook::ReadMe>
+=item L<Dist::Zilla::Role::Hooker>
 
 =back
 
