@@ -26,12 +26,12 @@
 
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-#pod =for :this This is C<Dist::Zilla::Role::Hooker> role documentation. Read this if you are going
-#pod to hack or extend C<Dist-Zilla-Plugin-Hook>, or use the role in your plugin.
+#pod =for :this This is C<Hooker> role documentation. Read this if you are going to hack or extend
+#pod C<Dist-Zilla-Plugin-Hook>, or use the role in your plugin.
 #pod
-#pod =for :that If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>. General
+#pod =for :those If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>. General
 #pod topics like getting source, building, installing, bug reporting and some others are covered in the
-#pod L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
+#pod F<README>.
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -46,7 +46,6 @@
 #pod = L<Dist::Zilla::Role>
 #pod = L<Dist::Zilla::Role::Plugin>
 #pod = L<Dist::Zilla::Plugin::Hook::Manual>
-#pod = L<Dist::Zilla::Plugin::Hook::ReadMe>
 #pod
 #pod =cut
 
@@ -56,7 +55,7 @@ use Moose::Role;
 use namespace::autoclean;
 
 # ABSTRACT: Run Perl code written in your plugin's F<dist.ini> section
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 with 'Dist::Zilla::Role::Plugin';
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
@@ -72,7 +71,7 @@ with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
 #pod Note: C<init_arg> attribute property set to ".". In F<dist.ini> file the Perl code should be
 #pod specified using this notation:
 #pod
-#pod     [Hook::Phase]
+#pod     [Hook::Role]
 #pod         . = …Perl code…
 #pod
 #pod =cut
@@ -94,25 +93,31 @@ has code => (
 #pod     $self->hook( @args );
 #pod
 #pod This is the primary method of the role. The method executes Perl code specified in C<code>
-#pod attribute with string C<eval>. The method passes arguments specified by the caller to the code, and
-#pod passes the code return value back to the caller. Calling context (list, scalar, or void) is
-#pod preserved. The method also hides all the lexical variables (except the variables documented below)
-#pod from code. The method intercepts warnings generated in code and logs them, but warnings do not stop
-#pod executing.
+#pod attribute (prepended with C<prologue>) with string C<eval>. The method passes arguments specified
+#pod by the caller to the code, and passes the code return value back to the caller. Calling context
+#pod (list, scalar, or void) is preserved. The method also hides all the lexical variables (except the
+#pod variables documented below) from code. The method intercepts warnings generated in code and logs
+#pod them, but warnings do not stop executing.
 #pod
 #pod Following lexical variables are exposed to the code intentionally:
 #pod
-#pod =for :list
+#pod =begin :list
+#pod
+#pod = C<@_>
+#pod C<hook> arguments, self-reference is already shifted!
+#pod
+#pod = C<$arg>
+#pod The same as C<$_[ 0 ]>.
+#pod
 #pod = C<$self>
 #pod = C<$plugin>
 #pod Reference to the plugin object executing the code (such as C<Hook::Init> or C<Hook::BeforeBuild>).
-#pod = C<$zilla>
+#pod
 #pod = C<$dist>
+#pod = C<$zilla>
 #pod Reference to C<Dist::Zilla> object, the same as C<< $self->zilla >>.
-#pod = C<$arg>
-#pod The same as C<$_[ 0 ]>.
-#pod = C<@_>
-#pod C<hook> arguments, self-reference is already shifted!
+#pod
+#pod =end :list
 #pod
 #pod If code dies, the method logs error message and aborts C<Dist::Zilla>.
 #pod
@@ -138,17 +143,17 @@ sub hook {                  ## no critic ( RequireArgUnpacking )
             eval(           ## no critic ( ProhibitStringyEval, RequireCheckingReturnValueOfEval )
                 join(
                     "\n",
-                    '#line 1 prologue',
+                    $self->line_directive( 'prologue' ),            # Make error repot nice.
                     $self->prologue,
-                    '#line 1 ' . $self->plugin_name,        # It makes error repoting nicier.
-                    $self->code
+                    $self->line_directive( $self->plugin_name ),    # Make error repot nice.
+                    $self->code,
                 )
             );
         };
     my $want = wantarray();
     my ( $err, @ret );
     {
-        local $@ = $@;                  # Leep outer `$@` intact.
+        local $@ = $@;                  # Keep outer `$@` intact.
         if ( $want ) {                  # Let us keep calling context.
             @ret = $code->( @_ );
         } elsif ( defined( $want ) ) {
@@ -168,9 +173,43 @@ sub hook {                  ## no critic ( RequireArgUnpacking )
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =method line_directive
+#pod
+#pod     $dir = $self->line_directive( $filename, $linenumber );
+#pod     $dir = $self->line_directive( $filename );
+#pod
+#pod The method returns Perl line directive, like
+#pod
+#pod     #line 1 "filename.ext"
+#pod
+#pod The method takes care about quotes. Perl line directive does not allow any quotes (escaped or not)
+#pod in filename, so directive
+#pod
+#pod     #line 1 "\"Assa\" project.txt"
+#pod
+#pod will be ignored. To avoid this, C<line_directive> replaces quotes in filename with apostrophes, e.
+#pod g.:
+#pod
+#pod     #line 1 "'Assa' project.txt"
+#pod
+#pod If line number is not specified, 1 will be used.
+#pod
+#pod =cut
+
+sub line_directive {
+    my ( $self, $file, $line ) = @_;
+    $file =~ s{"}{'}gx;     #   Perl `#line` directive does not allow quotes in filename.
+    if ( not defined( $line ) ) {
+        $line = 1;
+    };
+    return sprintf( '#line %d "%s"', $line, $file );
+};
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =method prologue
 #pod
-#pod     my @code = $self->prologue;
+#pod     @code = $self->prologue;
 #pod
 #pod The method returns prologue code.
 #pod
@@ -242,19 +281,19 @@ Dist::Zilla::Role::Hooker - Run Perl code written in your plugin's F<dist.ini> s
 
 =head1 VERSION
 
-Version 0.006, released on 2015-08-11 20:12 UTC.
+Version 0.007, released on 2015-08-13 19:35 UTC.
 
 =head1 WHAT?
 
 C<Dist-Zilla-Plugin-Hook> (or just C<Hook>) is a set of C<Dist-Zilla> plugins. Every plugin executes Perl
 code inlined into F<dist.ini> at particular stage of build process.
 
-This is C<Dist::Zilla::Role::Hooker> role documentation. Read this if you are going
-to hack or extend C<Dist-Zilla-Plugin-Hook>, or use the role in your plugin.
+This is C<Hooker> role documentation. Read this if you are going to hack or extend
+C<Dist-Zilla-Plugin-Hook>, or use the role in your plugin.
 
 If you want to write C<Dist::Zilla> plugin directly in F<dist.ini>, read the L<manual|Dist::Zilla::Plugin::Hook::Manual>. General
 topics like getting source, building, installing, bug reporting and some others are covered in the
-L<readme|Dist::Zilla::Plugin::Hook::ReadMe>.
+F<README>.
 
 =head1 DESCRIPTION
 
@@ -273,7 +312,7 @@ ArrayRef[Str], read-only. Default value is empty array (i. e. no code).
 Note: C<init_arg> attribute property set to ".". In F<dist.ini> file the Perl code should be
 specified using this notation:
 
-    [Hook::Phase]
+    [Hook::Role]
         . = …Perl code…
 
 =head1 OBJECT METHODS
@@ -285,43 +324,64 @@ specified using this notation:
     $self->hook( @args );
 
 This is the primary method of the role. The method executes Perl code specified in C<code>
-attribute with string C<eval>. The method passes arguments specified by the caller to the code, and
-passes the code return value back to the caller. Calling context (list, scalar, or void) is
-preserved. The method also hides all the lexical variables (except the variables documented below)
-from code. The method intercepts warnings generated in code and logs them, but warnings do not stop
-executing.
+attribute (prepended with C<prologue>) with string C<eval>. The method passes arguments specified
+by the caller to the code, and passes the code return value back to the caller. Calling context
+(list, scalar, or void) is preserved. The method also hides all the lexical variables (except the
+variables documented below) from code. The method intercepts warnings generated in code and logs
+them, but warnings do not stop executing.
 
 Following lexical variables are exposed to the code intentionally:
 
 =over 4
 
+=item C<@_>
+
+C<hook> arguments, self-reference is already shifted!
+
+=item C<$arg>
+
+The same as C<$_[ 0 ]>.
+
 =item C<$self>
 
 =item C<$plugin>
 
 Reference to the plugin object executing the code (such as C<Hook::Init> or C<Hook::BeforeBuild>).
 
-=item C<$zilla>
-
 =item C<$dist>
 
+=item C<$zilla>
+
 Reference to C<Dist::Zilla> object, the same as C<< $self->zilla >>.
 
-=item C<$arg>
-
-The same as C<$_[ 0 ]>.
-
-=item C<@_>
-
-C<hook> arguments, self-reference is already shifted!
-
 =back
 
 If code dies, the method logs error message and aborts C<Dist::Zilla>.
 
+=head2 line_directive
+
+    $dir = $self->line_directive( $filename, $linenumber );
+    $dir = $self->line_directive( $filename );
+
+The method returns Perl line directive, like
+
+    #line 1 "filename.ext"
+
+The method takes care about quotes. Perl line directive does not allow any quotes (escaped or not)
+in filename, so directive
+
+    #line 1 "\"Assa\" project.txt"
+
+will be ignored. To avoid this, C<line_directive> replaces quotes in filename with apostrophes, e.
+g.:
+
+    #line 1 "'Assa' project.txt"
+
+If line number is not specified, 1 will be used.
+
 =head2 prologue
 
-    my @code = $self->prologue;
+    @code = $self->prologue;
 
 The method returns prologue code.
 
@@ -343,8 +403,6 @@ The method tells C<Dist::Zilla> that dot (C<.>) is a multi-value option.
 
 =item L<Dist::Zilla::Plugin::Hook::Manual>
 
-=item L<Dist::Zilla::Plugin::Hook::ReadMe>
-
 =back
 
 =head1 AUTHOR
