@@ -36,7 +36,7 @@ use Test::Deep qw{ cmp_deeply };
 
 sub build_msg_grepper {
     my ( $self ) = @_;
-    return sub { $_ =~ qr{^\[Hook::.+?\] } };
+    return sub { $_ =~ qr{^\[.*Hook.*\] }i };
 };
 
 1;
